@@ -1,3 +1,4 @@
+use crate::app::WrapMode;
 use crate::common::InputMode;
 use crate::history::BufferHistoryContainer;
 use crate::util::events::{CsvlensEvent, CsvlensEvents};
@@ -37,8 +38,9 @@ pub enum Control {
     Select,
     CopySelection,
     ToggleSelectionType,
-    ToggleLineWrap(bool),
+    ToggleLineWrap(WrapMode),
     ToggleSort,
+    ToggleNaturalSort,
     Reset,
     Help,
     UnknownOption(String),
@@ -183,6 +185,7 @@ impl InputHandler {
                 KeyCode::Char('l') => Control::ScrollPageRight,
                 KeyCode::Left => Control::ScrollLeftMost,
                 KeyCode::Right => Control::ScrollRightMost,
+                KeyCode::Char('j') => Control::ToggleNaturalSort,
                 _ => Control::Nothing,
             },
             _ => Control::Nothing,
@@ -293,11 +296,11 @@ impl InputHandler {
             }
             KeyCode::Char('S') => {
                 self.reset_buffer();
-                Control::ToggleLineWrap(false)
+                Control::ToggleLineWrap(WrapMode::Chars)
             }
             KeyCode::Char('W') | KeyCode::Char('w') => {
                 self.reset_buffer();
-                Control::ToggleLineWrap(true)
+                Control::ToggleLineWrap(WrapMode::Words)
             }
             KeyCode::Char(x) => {
                 self.reset_buffer();
