@@ -3,6 +3,7 @@ use crate::csv::Row;
 use crate::find;
 use crate::sort;
 use crate::sort::SortOrder;
+use crate::sort::SortType;
 use crate::theme::Theme;
 use crate::view;
 use crate::view::Header;
@@ -31,6 +32,20 @@ const NUM_SPACES_AFTER_LINE_NUMBER: u16 = 2;
 const NUM_SPACES_BETWEEN_COLUMNS: u16 = 4;
 const MAX_COLUMN_WIDTH_FRACTION: f32 = 0.3;
 
+pub fn set_line_safe(
+    buf: &mut Buffer,
+    x: u16,
+    y: u16,
+    line: &Line<'_>,
+    max_width: u16,
+) -> Option<(u16, u16)> {
+    if y < buf.area.bottom() {
+        Some(buf.set_line(x, y, line, max_width))
+    } else {
+        None
+    }
+}
+
 #[derive(Debug)]
 pub struct ColumnWidthOverrides {
     overrides: HashMap<usize, u16>,
@@ -244,12 +259,12 @@ impl<'a> CsvTable<'a> {
         for (i, row) in rows.iter().enumerate() {
             let row_num_formatted = row.record_num.to_string();
             let mut style = Style::default().fg(state.theme.row_number);
-            if let Some(selection) = &state.selection {
-                if selection.row.is_selected(i) {
-                    style = style
-                        .add_modifier(Modifier::BOLD)
-                        .add_modifier(Modifier::UNDERLINED);
-                }
+            if let Some(selection) = &state.selection
+                && selection.row.is_selected(i)
+            {
+                style = style
+                    .add_modifier(Modifier::BOLD)
+                    .add_modifier(Modifier::UNDERLINED);
             }
             let span = Span::styled(row_num_formatted, style);
             buf.set_span(0, y, &span, view_layout.row_number_layout.max_length);
@@ -380,14 +395,20 @@ impl<'a> CsvTable<'a> {
     }
 
     fn get_effective_column_name(&self, column_name: &str, sorter_state: &SorterState) -> String {
-        if let SorterState::Enabled(info) = sorter_state {
-            if info.status == sort::SorterStatus::Finished && info.column_name == column_name {
-                let indicator = match info.order {
-                    SortOrder::Ascending => "▴",
-                    SortOrder::Descending => "▾",
-                };
-                return format!("{} [{}]", column_name, indicator);
-            }
+        if let SorterState::Enabled(info) = sorter_state
+            && info.status == sort::SorterStatus::Finished
+            && info.column_name == column_name
+        {
+            let indicator = match info.order {
+                SortOrder::Ascending => "▴",
+                SortOrder::Descending => "▾",
+            };
+
+            let sort_type_indicator = match info.sort_type {
+                SortType::Natural => "N",
+                _ => "",
+            };
+            return format!("{} [{}{}]", column_name, indicator, sort_type_indicator);
         }
         column_name.to_string()
     }
@@ -435,10 +456,10 @@ impl<'a> CsvTable<'a> {
             }
             if let RowType::Header = row_type {
                 content_style = content_style.add_modifier(Modifier::BOLD);
-                if let Some(selection) = &state.selection {
-                    if selection.column.is_selected(num_cols_rendered as usize) {
-                        content_style = content_style.add_modifier(Modifier::UNDERLINED);
-                    }
+                if let Some(selection) = &state.selection
+                    && selection.column.is_selected(num_cols_rendered as usize)
+                {
+                    content_style = content_style.add_modifier(Modifier::UNDERLINED);
                 }
             }
             let is_selected = if let Some(selection) = &state.selection {
@@ -467,10 +488,11 @@ impl<'a> CsvTable<'a> {
             let should_highlight_cell = |active: &FinderActiveState, content: &str| {
                 // Only highlight the selected column in column selection mode. But header search is
                 // always across all columns regardless of the selection mode.
-                if let Some((target_column_index, _)) = active.column_index {
-                    if target_column_index != col_index && matches!(row_type, RowType::Record(_)) {
-                        return false;
-                    }
+                if let Some((target_column_index, _)) = active.column_index
+                    && target_column_index != col_index
+                    && matches!(row_type, RowType::Record(_))
+                {
+                    return false;
                 }
                 if active.is_filter && matches!(row_type, RowType::Header) {
                     return false;
@@ -485,13 +507,12 @@ impl<'a> CsvTable<'a> {
                     if let Some(found_record) = &active.found_record {
                         match found_record {
                             find::FoundEntry::Row(entry) => {
-                                if let Some(row_index) = row_index {
-                                    if row_index == entry.row_index()
-                                        && entry.column_index() == col_index
-                                    {
-                                        highlight_style = highlight_style
-                                            .bg(state.theme.found_selected_background);
-                                    }
+                                if let Some(row_index) = row_index
+                                    && row_index == entry.row_index()
+                                    && entry.column_index() == col_index
+                                {
+                                    highlight_style =
+                                        highlight_style.bg(state.theme.found_selected_background);
                                 }
                             }
                             find::FoundEntry::Header(entry) => {
@@ -635,15 +656,16 @@ impl<'a> CsvTable<'a> {
             if let Some(mut line) = line_wrapper.next() {
                 // There is some content to render. Truncate with ... if there is no more vertical
                 // space available.
-                if offset == height - 1 && !line_wrapper.finished() {
-                    if let Some(last_span) = line.spans.pop() {
-                        let truncate_length = last_span.width().saturating_sub(SUFFIX_LEN as usize);
-                        let truncated_content: String =
-                            last_span.content.chars().take(truncate_length).collect();
-                        let truncated_span = Span::styled(truncated_content, last_span.style);
-                        line.spans.push(truncated_span);
-                        line.spans.push(Span::styled(SUFFIX, last_span.style));
-                    }
+                if offset == height - 1
+                    && !line_wrapper.finished()
+                    && let Some(last_span) = line.spans.pop()
+                {
+                    let truncate_length = last_span.width().saturating_sub(SUFFIX_LEN as usize);
+                    let truncated_content: String =
+                        last_span.content.chars().take(truncate_length).collect();
+                    let truncated_span = Span::styled(truncated_content, last_span.style);
+                    line.spans.push(truncated_span);
+                    line.spans.push(Span::styled(SUFFIX, last_span.style));
                 }
                 let padding_width = min(
                     (effective_width as usize + buffer_space).saturating_sub(line.width()),
@@ -653,7 +675,7 @@ impl<'a> CsvTable<'a> {
                     line.spans
                         .push(Span::styled(" ".repeat(padding_width), filler_style.style));
                 }
-                buf.set_line(x, y + offset, &line, width);
+                set_line_safe(buf, x, y + offset, &line, width);
             } else {
                 // There are extra vertical spaces that are just empty lines. Fill them with the
                 // correct style.
@@ -670,7 +692,7 @@ impl<'a> CsvTable<'a> {
                     content = format!("{SUFFIX}{}", truncated_content.as_str());
                 }
                 let span = Span::styled(content, filler_style.style);
-                buf.set_line(x, y + offset, &Line::from(vec![span]), width);
+                set_line_safe(buf, x, y + offset, &Line::from(vec![span]), width);
             }
         }
     }
@@ -1126,6 +1148,7 @@ impl SorterState {
             status: sorter.status(),
             column_name: sorter.column_name().to_string(),
             order: sort_order,
+            sort_type: sorter.sort_type(),
         })
     }
 }
@@ -1134,11 +1157,16 @@ struct SorterInfo {
     status: sort::SorterStatus,
     column_name: String,
     order: SortOrder,
+    sort_type: sort::SortType,
 }
 
 impl SorterInfo {
     fn status_line(&self) -> String {
-        let prefix = format!("[Sorting by {}", self.column_name);
+        let sort_type_str = match self.sort_type {
+            sort::SortType::Natural => "natural",
+            sort::SortType::Auto => "auto based on type",
+        };
+        let prefix = format!("[Sorting by {} ({})", self.column_name, sort_type_str);
         match &self.status {
             sort::SorterStatus::Running => format!("{prefix}...]").to_string(),
             sort::SorterStatus::Error(error_msg) => {
@@ -1159,6 +1187,7 @@ pub struct DebugStats {
     show_stats: bool,
     rows_view_stats: Option<crate::view::PerfStats>,
     finder_elapsed: Option<Duration>,
+    sorter_elapsed: Option<Duration>,
     render_elapsed: Option<Duration>,
 }
 
@@ -1168,6 +1197,7 @@ impl DebugStats {
             show_stats: false,
             rows_view_stats: None,
             finder_elapsed: None,
+            sorter_elapsed: None,
             render_elapsed: None,
         }
     }
@@ -1184,6 +1214,10 @@ impl DebugStats {
         self.finder_elapsed = elapsed;
     }
 
+    pub fn sorter_elapsed(&mut self, elapsed: Option<Duration>) {
+        self.sorter_elapsed = elapsed;
+    }
+
     pub fn render_elapsed(&mut self, elapsed: Option<Duration>) {
         self.render_elapsed = elapsed;
     }
@@ -1211,6 +1245,9 @@ impl DebugStats {
         if let Some(elapsed) = self.finder_elapsed {
             line += format!(" finder:{:.3}ms", elapsed.as_micros() as f64 / 1000.0).as_str();
         }
+        if let Some(elapsed) = self.sorter_elapsed {
+            line += format!(" sorter:{:.3}ms", elapsed.as_micros() as f64 / 1000.0).as_str();
+        }
         if let Some(elapsed) = self.render_elapsed {
             line += format!(" render:{:.3}ms", elapsed.as_micros() as f64 / 1000.0).as_str();
         }
@@ -1347,3 +1384,32 @@ impl CsvTableState {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::sort::{SortType, SorterStatus};
+
+    #[test]
+    fn test_sorter_info_status_line() {
+        let info = SorterInfo {
+            status: SorterStatus::Running,
+            column_name: "test_column".to_string(),
+            order: SortOrder::Ascending,
+            sort_type: SortType::Natural,
+        };
+
+        let status_line = info.status_line();
+        assert!(status_line.contains("Sorting by test_column (natural)"));
+
+        let info_lex = SorterInfo {
+            status: SorterStatus::Running,
+            column_name: "test_column".to_string(),
+            order: SortOrder::Ascending,
+            sort_type: SortType::Auto,
+        };
+
+        let status_line_lex = info_lex.status_line();
+        assert!(status_line_lex.contains("Sorting by test_column (auto based on type)"));
+    }
+}
